@@ -1,49 +1,34 @@
-package Data::Domain::URI;
-
+use 5.008;
 use strict;
 use warnings;
+
+package Data::Domain::URI;
+our $VERSION = '1.100850';
+# ABSTRACT: Data domain classes for URIs
 use Data::Domain::SemanticAdapter;
-
-
-our $VERSION = '0.02';
-
-
-use base 'Exporter';
-
-
+use Exporter qw(import);
 our %map = (
     URI_Fax  => 'URI::fax',
     URI_File => 'URI::file',
     URI_FTP  => 'URI::ftp',
     URI_HTTP => 'URI::http',
 );
-
-
-our %EXPORT_TAGS = (
-    util => [ keys %map ],
-);
-
-
+our %EXPORT_TAGS = (util => [ keys %map ],);
 our @EXPORT_OK = @{ $EXPORT_TAGS{all} = [ map { @$_ } values %EXPORT_TAGS ] };
-
-
 Data::Domain::SemanticAdapter::install_shortcuts(%map);
-
-
 1;
 
 
 __END__
-
-
+=pod
 
 =head1 NAME
 
 Data::Domain::URI - Data domain classes for URIs
 
-=head1 SYNOPSIS
+=head1 VERSION
 
-    Data::Domain::URI->new;
+version 1.100850
 
 =head1 DESCRIPTION
 
@@ -52,19 +37,19 @@ types.
 
 =over 4
 
-=item fax
+=item C<fax>
 
 See L<Data::Domain::URI::fax>.
 
-=item file
+=item C<file>
 
 See L<Data::Domain::URI::file>.
 
-=item ftp
+=item C<ftp>
 
 See L<Data::Domain::URI::ftp>.
 
-=item http
+=item C<http>
 
 See L<Data::Domain::URI::http>.
 
@@ -99,64 +84,39 @@ passed on to the object's constructor.
 
 By using the C<:all> tag, you can import all of them.
 
-Data::Domain::URI inherits from L<Exporter>.
+=head1 INSTALLATION
 
-The superclass L<Exporter> defines these methods and functions:
-
-    as_heavy(), export(), export_fail(), export_ok_tags(), export_tags(),
-    export_to_level(), import(), require_version()
-
-=head1 METHODS
-
-=over 4
-
-
-
-=back
-
-=head1 TODO
-
-Add the other URI classes supported by L<Regexp::Common::URI> as soon as they
-are available via L<Data::Semantic::URI>.
-
-=head1 TAGS
-
-If you talk about this module in blogs, on del.icio.us or anywhere else,
-please use the C<datadomainuri> tag.
-
-=head1 VERSION 
-                   
-This document describes version 0.02 of L<Data::Domain::URI>.
+See perlmodinstall for information and options on installing Perl modules.
 
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
-Please report any bugs or feature requests to
-C<<bug-data-domain-uri@rt.cpan.org>>, or through the web interface at
-L<http://rt.cpan.org>.
-
-=head1 INSTALLATION
-
-See perlmodinstall for information and options on installing Perl modules.
+Please report any bugs or feature requests through the web interface at
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Domain-URI>.
 
 =head1 AVAILABILITY
 
 The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see
+L<http://search.cpan.org/dist/Data-Domain-URI/>.
+
+The development version lives at
+L<http://github.com/hanekomu/Data-Domain-URI/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
 
 =head1 AUTHOR
 
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+  Marcel Gruenauer <marcel@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007 by Marcel GrE<uuml>nauer
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This software is copyright (c) 2007 by Marcel Gruenauer.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
